# doskillthread.mak - Make doskillthread.exe as OS/2 Watcom VIO c app with standard options

# 2008-06-16 SHL Baseline
# 2017-11-28 SHL Update

# Assumes
# set INCLUDE=*;D:\WATCOM\H;D:\TOOLKIT\H;C:\INCLUDE
# set LIB=*;D:\TOOLKIT\LIB;;D:\WATCOM\LIB386\OS2;D:\WATCOM\LIB386

# Required environment variables
# WATCOM
# VENDOR
# BUILDVER
# BUILDMACH
# BUILDTIME

# Supported environment variables
# Define DEBUG in environment for debug build
# Define EXCEPTQ in environment to build with exceptq support

# Check required environment variables

!ifndef %WATCOM
!error WATCOM not defined
!endif

!ifndef %BUILDTIME
!error BUILDTIME not defined
!endif

!ifndef %BUILDVER
!error BUILDVER not defined
!endif

!ifndef %BUILDMACH
!error BUILDMACH not defined
!endif

!ifndef %VENDOR
!error VENDOR not defined
!endif

.ERASE

.SUFFIXES:
.SUFFIXES: .sys .obj .asm .inc .def .lrf .ref .lst .sym .map .c .cpp .h .lib

NAME = doskillthread
DESC = DosKillThread stress test. Copyright 2017 Steven Levine & Associates., Inc.
EXENAME = $(NAME).exe

CC = wcc386

!ifndef DEBUG			# if not defined on wmake command line
!ifdef %DEBUG			# if defined in environment
DEBUG = $(%DEBUG)		# use value from environment
!endif
!endif

!ifndef WARNALL			# if not defined on wmake command line
!ifdef %WARNALL			# if defined in environment
WARNALL = %WARNALL		# use value from environment
!endif
!endif

!ifndef EXCEPTQ			# if not defined on wmake command line
!ifdef %EXCEPTQ			# if defined in environment
EXCEPTQ = %EXCEPTQ		# use value from environment
!endif
!endif

# wcc/wpp flags
# -bc           console app
#  bd		build target is a Dynamic Link Library (DLL) (see bd)
# -bm           multithread libs
# -bt=os2       target
# -d2           full debug
# -hd           dwarf
# -j		signed char
# -mf           flat
# -of           generate traceable stack frames
# -olinars      optimze loops, inline, e(n)able fp recip, relax (a)lias, reordering, space
# -s            disable stack checks
# -sg		generate calls to grow the stack
# -st           touch stack through SS first
# -wcd###	disable warning
# -wce###	enable warning
# -wc?14	no reference to symbol
# -wc?726	no reference to formal parameter
# -wc?202	no reference to defined static
# -we		treat all warnings as errors
# -wx           max warnings
# -ze           define _cdecl etc.
# -zfp          disable fs use
# -zgp          disable gs use
# -zp4          align 4
# -zq           quiet

# Order dependent flags
!ifdef DEBUG
CFLAGS = -bt=os2 -mf -bm -of -olirs -d2 -s -j -wx -zfp -zgp      -hd
!else
CFLAGS = -bt=os2 -mf -bm -of -olirs     -s -j -wx -zfp -zgp      -hd
!endif

# Order independent flags
CFLAGS += -zq

!ifdef WARNALL
CFLAGS += -wce14 -wce726 -wce202 -we
!else
CFLAGS += -wcd202
!endif

!ifdef EXCEPTQ
CFLAGS += -dEXCEPTQ
!endif

LINK = wlink

#################
# Inference rules
#################

.c.obj: .AUTODEPEND $(__MAKEFILES__)
     $(CC) $(CFLAGS) $[@

##############
# Object files
##############

# objects built here
OBJS = $(NAME).obj

# objects built elsewhere
EXTRA_OBJS =

# all object files
ALL_OBJS = $(OBJS) $(EXTRA_OBJS)

###############
# Library files
###############

# libraries built here
LIBS =

# libraries built elsewhere
EXTRA_LIBS = os2386.lib slawat.lib

# all libraries files
ALL_LIBS = $(LIBS) $(EXTRA_LIBS)

#############
# Build rules
#############

all: $(EXENAME) $(__MAKEFILES__) .SYMBOLIC

# Avoid lost spaces in @%write
FILL = xxxx

$(NAME).lrf: $(__MAKEFILES__)
   @%write $^@ system os2v2
   @%write $^@ option verbose
   @%write $^@ option cache
   @%write $^@ option caseexact
!ifdef DEBUG
    @%write $^@ debug dwarf all
!endif
   @%write $^@ option map
   @%write $^@ op desc '@$#$(%VENDOR):$(%BUILDVER)$#@$#$#1$#$# $(%BUILDTIME) $(FILL:x= ) $(%BUILDMACH)::EN:US:0:U:@@$(DESC)'
   @%write $^@ name $(NAME)
   @for %f in ($(ALL_OBJS)) do @%append $^@ file %f
   @for %f in ($(ALL_LIBS)) do @%append $^@ library %f
!ifdef EXCEPTQ
    @%write $^@ file exceptq.lib
!endif

$(EXENAME): $(OBJS) $(__MAKEFILES__) $(NAME).lrf
   $(LINK) @$(NAME).lrf
!ifndef DEBUG
  lxlite -B- -X- $@
!endif

lxlite: $(EXENAME) .SYMBOLIC
    dir $<
    lxlite -X- -B- $<
    bldlevel $<
    dir $<

strip: .SYMBOLIC
   dir /km $(EXENAME)
   @echo.
   -wstrip $(EXENAME)
   lxlite -B- $(EXENAME)
   @echo.
   dir /km $(EXENAME)

zip: $(NAME).zip .SYMBOLIC

$(NAME).zip: $(EXENAME).exe
    zip -j9o $@ $<
    unzip -t $@
    unzip -v $@

distclean: .SYMBOLIC
  -del $(NAME).err
  -del $(NAME).lrf
  -del $(NAME).map
  -del $(NAME).mbr
  -del $(NAME).sym
  -del $(OBJS)

clean: distclean .SYMBOLIC
  -del $(EXENAME).exe

# eof
